@@ -1,6 +1,6 @@
 # Zile-specific library functions
 #
-# Copyright (c) 2010 Free Software Foundation, Inc.
+# Copyright (c) 2010-2020 Free Software Foundation, Inc.
 #
 # This file is part of GNU Zile.
 #
@@ -19,20 +19,26 @@
 # Free Software Foundation, Fifth Floor, 51 Franklin Street, Boston,
 # MA 02111-1301, USA.
 
+sub get_bindings {
+  my ($file) = @_;
+  open IN, "<$file";
+  my $bindings = do { local $/ = undef; <IN> };
+  return eval $bindings;
+}
 
-# Parse re-usable C headers
-sub false { 0; }
-sub true { 1; }
-sub X { @xarg = @_; }
-$D = $O = $A = \&X;
+sub expand_keystrokes {
+  my ($doc, $bindings) = @_;
+  $doc =~ s/\\\\\[([a-z-]+)\]/@{$bindings->{$1}}[0]/ge;
+  return escape_for_C($doc);
+}
 
-# Turn texinfo markup into plain text
-sub texi {
+sub escape_for_C {
   my ($s) = @_;
-  $s =~ s/\@i\{([^}]+)}/uc($1)/ge;
-  $s =~ s/\@kbd\{([^}]+)}/\1/g;
-  $s =~ s/\@samp\{([^}]+)}/\1/g;
-  $s =~ s/\@itemize%s[^\n]*\n//g;
-  $s =~ s/\@end%s[^\n]*\n//g;
+  $s =~ s/\\/\\\\/g;
+  $s =~ s/\n/\\n/g;
+  $s =~ s/\"/\\\"/g;
   return $s;
 }
+
+
+1;
