@@ -115,16 +115,12 @@ static Binding
 search_key (Binding tree, gl_list_t keys, size_t from)
 {
   Binding p = search_node (tree, (size_t) gl_list_get_at (keys, from));
-
-  if (p != NULL)
-    {
-      if (gl_list_size (keys) - from == 1)
-        return p;
-      else
-        return search_key (p, keys, from + 1);
-    }
-
-  return NULL;
+  if (p == NULL)
+    return NULL;
+  else if (gl_list_size (keys) - from == 1)
+    return p;
+  else
+    return search_key (p, keys, from + 1);
 }
 
 size_t
@@ -205,7 +201,7 @@ get_function_by_keys (gl_list_t keys)
 static bool
 self_insert_command (void)
 {
-  int ret = true;
+  bool ret = true;
   /* Mask out ~KBD_CTRL to allow control sequences to be themselves. */
   int key = (int) (lastkey () & ~KBD_CTRL);
   deactivate_mark ();
@@ -249,8 +245,8 @@ set_this_command (Function cmd)
   _this_command = cmd;
 }
 
-le *
-call_command (Function f, int uniarg, bool uniflag, le *branch)
+bool
+call_command (Function f, long uniarg, le *branch)
 {
   thisflag = lastflag & FLAG_DEFINING_MACRO;
   undo_start_sequence ();
@@ -262,7 +258,7 @@ call_command (Function f, int uniarg, bool uniflag, le *branch)
 
   /* Execute the command. */
   _this_command = f;
-  le *ok = f (uniarg, uniflag, branch);
+  bool ok = f (uniarg, branch);
   _last_command = _this_command;
 
   /* Only add keystrokes if we were already in macro defining mode
@@ -285,7 +281,7 @@ get_and_run_command (void)
   minibuf_clear ();
 
   if (f != NULL)
-    call_command (f, last_uniarg, (lastflag & FLAG_SET_UNIARG) != 0, NULL);
+    call_command (f, last_uniarg, (lastflag & FLAG_SET_UNIARG) ? NULL : leNIL);
   else
     minibuf_error ("%s is undefined", astr_cstr (keyvectodesc (keys)));
 }
@@ -314,120 +310,9 @@ init_default_bindings (void)
         }
     }
 
-  astr as = astr_new_cstr ("\
-(global-set-key \"\\M-m\" 'back-to-indentation)\
-(global-set-key \"\\LEFT\" 'backward-char)\
-(global-set-key \"\\C-b\" 'backward-char)\
-(global-set-key \"\\BACKSPACE\" 'backward-delete-char)\
-(global-set-key \"\\M-\\BACKSPACE\" 'backward-kill-word)\
-(global-set-key \"\\M-{\" 'backward-paragraph)\
-(global-set-key \"\\C-\\M-b\" 'backward-sexp)\
-(global-set-key \"\\M-b\" 'backward-word)\
-(global-set-key \"\\M-<\" 'beginning-of-buffer)\
-(global-set-key \"\\HOME\" 'beginning-of-line)\
-(global-set-key \"\\C-a\" 'beginning-of-line)\
-(global-set-key \"\\C-xe\" 'call-last-kbd-macro)\
-(global-set-key \"\\M-c\" 'capitalize-word)\
-(global-set-key \"\\M-w\" 'copy-region-as-kill)\
-(global-set-key \"\\C-xrs\" 'copy-to-register)\
-(global-set-key \"\\C-xrx\" 'copy-to-register)\
-(global-set-key \"\\C-x\\C-o\" 'delete-blank-lines)\
-(global-set-key \"\\DELETE\" 'delete-char)\
-(global-set-key \"\\C-d\" 'delete-char)\
-(global-set-key \"\\M-\\\\\" 'delete-horizontal-space)\
-(global-set-key \"\\C-x1\" 'delete-other-windows)\
-(global-set-key \"\\C-x0\" 'delete-window)\
-(global-set-key \"\\C-hb\" 'describe-bindings)\
-(global-set-key \"\\F1b\" 'describe-bindings)\
-(global-set-key \"\\C-hf\" 'describe-function)\
-(global-set-key \"\\F1f\" 'describe-function)\
-(global-set-key \"\\C-hk\" 'describe-key)\
-(global-set-key \"\\F1k\" 'describe-key)\
-(global-set-key \"\\C-hv\" 'describe-variable)\
-(global-set-key \"\\F1v\" 'describe-variable)\
-(global-set-key \"\\C-x\\C-l\" 'downcase-region)\
-(global-set-key \"\\M-l\" 'downcase-word)\
-(global-set-key \"\\C-x)\" 'end-kbd-macro)\
-(global-set-key \"\\M->\" 'end-of-buffer)\
-(global-set-key \"\\END\" 'end-of-line)\
-(global-set-key \"\\C-e\" 'end-of-line)\
-(global-set-key \"\\C-x^\" 'enlarge-window)\
-(global-set-key \"\\C-x\\C-x\" 'exchange-point-and-mark)\
-(global-set-key \"\\M-x\" 'execute-extended-command)\
-(global-set-key \"\\M-q\" 'fill-paragraph)\
-(global-set-key \"\\C-x\\C-v\" 'find-alternate-file)\
-(global-set-key \"\\C-x\\C-f\" 'find-file)\
-(global-set-key \"\\C-x\\C-r\" 'find-file-read-only)\
-(global-set-key \"\\RIGHT\" 'forward-char)\
-(global-set-key \"\\C-f\" 'forward-char)\
-(global-set-key \"\\M-}\" 'forward-paragraph)\
-(global-set-key \"\\C-\\M-f\" 'forward-sexp)\
-(global-set-key \"\\M-f\" 'forward-word)\
-(global-set-key \"\\M-gg\" 'goto-line)\
-(global-set-key \"\\M-g\\M-g\" 'goto-line)\
-(global-set-key \"\\TAB\" 'indent-for-tab-command)\
-(global-set-key \"\\C-xi\" 'insert-file)\
-(global-set-key \"\\C-xri\" 'insert-register)\
-(global-set-key \"\\C-xrg\" 'insert-register)\
-(global-set-key \"\\C-r\" 'isearch-backward)\
-(global-set-key \"\\C-\\M-r\" 'isearch-backward-regexp)\
-(global-set-key \"\\C-s\" 'isearch-forward)\
-(global-set-key \"\\C-\\M-s\" 'isearch-forward-regexp)\
-(global-set-key \"\\M-\\SPC\" 'just-one-space)\
-(global-set-key \"\\C-g\" 'keyboard-quit)\
-(global-set-key \"\\C-xk\" 'kill-buffer)\
-(global-set-key \"\\C-k\" 'kill-line)\
-(global-set-key \"\\C-w\" 'kill-region)\
-(global-set-key \"\\C-\\M-k\" 'kill-sexp)\
-(global-set-key \"\\M-d\" 'kill-word)\
-(global-set-key \"\\C-x\\C-b\" 'list-buffers)\
-(global-set-key \"\\M-h\" 'mark-paragraph)\
-(global-set-key \"\\C-\\M-@\" 'mark-sexp)\
-(global-set-key \"\\C-xh\" 'mark-whole-buffer)\
-(global-set-key \"\\M-@\" 'mark-word)\
-(global-set-key \"\\RET\" 'newline)\
-(global-set-key \"\\C-j\" 'newline-and-indent)\
-(global-set-key \"\\DOWN\" 'next-line)\
-(global-set-key \"\\C-n\" 'next-line)\
-(global-set-key \"\\C-o\" 'open-line)\
-(global-set-key \"\\C-xo\" 'other-window)\
-(global-set-key \"\\UP\" 'previous-line)\
-(global-set-key \"\\C-p\" 'previous-line)\
-(global-set-key \"\\M-%\" 'query-replace)\
-(global-set-key \"\\C-q\" 'quoted-insert)\
-(global-set-key \"\\C-l\" 'recenter)\
-(global-set-key \"\\C-x\\C-s\" 'save-buffer)\
-(global-set-key \"\\C-x\\C-c\" 'save-buffers-kill-emacs)\
-(global-set-key \"\\C-xs\" 'save-some-buffers)\
-(global-set-key \"\\PRIOR\" 'scroll-down)\
-(global-set-key \"\\M-v\" 'scroll-down)\
-(global-set-key \"\\NEXT\" 'scroll-up)\
-(global-set-key \"\\C-v\" 'scroll-up)\
-(global-set-key \"\\C-xf\" 'set-fill-column)\
-(global-set-key \"\\C-@\" 'set-mark-command)\
-(global-set-key \"\\M-!\" 'shell-command)\
-(global-set-key \"\\M-|\" 'shell-command-on-region)\
-(global-set-key \"\\C-x2\" 'split-window)\
-(global-set-key \"\\C-x(\" 'start-kbd-macro)\
-(global-set-key \"\\C-x\\C-z\" 'suspend-emacs)\
-(global-set-key \"\\C-z\" 'suspend-emacs)\
-(global-set-key \"\\C-xb\" 'switch-to-buffer)\
-(global-set-key \"\\M-i\" 'tab-to-tab-stop)\
-(global-set-key \"\\C-x\\C-q\" 'toggle-read-only)\
-(global-set-key \"\\C-t\" 'transpose-chars)\
-(global-set-key \"\\C-x\\C-t\" 'transpose-lines)\
-(global-set-key \"\\C-\\M-t\" 'transpose-sexps)\
-(global-set-key \"\\M-t\" 'transpose-words)\
-(global-set-key \"\\C-xu\" 'undo)\
-(global-set-key \"\\C-_\" 'undo)\
-(global-set-key \"\\C-u\" 'universal-argument)\
-(global-set-key \"\\C-x\\C-u\" 'upcase-region)\
-(global-set-key \"\\M-u\" 'upcase-word)\
-(global-set-key \"\\C-hw\" 'where-is)\
-(global-set-key \"\\F1w\" 'where-is)\
-(global-set-key \"\\C-x\\C-w\" 'write-file)\
-(global-set-key \"\\C-y\" 'yank)\
-");
+  astr as = astr_new_cstr (
+#include "tbl_bindings.h"
+);
   lisp_loadstring (as);
 }
 
@@ -450,7 +335,7 @@ sequence.
       if (keys == NULL)
         {
           minibuf_error ("Key sequence %s is invalid", astr_cstr (keystr));
-          return leNIL;
+          return false;
         }
     }
   else
@@ -465,13 +350,13 @@ sequence.
     name = minibuf_read_function_name ("Set key %s to command: ",
                                        astr_cstr (keystr));
   if (name == NULL)
-    return leNIL;
+    return false;
 
   func = get_function (astr_cstr (name));
   if (func == NULL) /* Possible if called non-interactively */
     {
       minibuf_error ("No such function `%s'", astr_cstr (name));
-      return leNIL;
+      return false;
     }
   bind_key_vec (root_bindings, keys, 0, func);
 }
@@ -505,11 +390,11 @@ walk_bindings_tree (Binding tree, gl_list_t keys,
 }
 
 static void
-walk_bindings (Binding tree, void (*process) (astr key, Binding p, void *st),
-               void *st)
+walk_bindings (void (*process) (astr key, Binding p, void *st), void *st)
 {
-  walk_bindings_tree (tree, gl_list_create_empty (GL_LINKED_LIST,
-                                                  NULL, NULL, NULL, true), process, st);
+  walk_bindings_tree (root_bindings,
+                      gl_list_create_empty (GL_LINKED_LIST,
+                                            NULL, NULL, NULL, true), process, st);
 }
 
 typedef struct
@@ -540,7 +425,7 @@ Argument is a command name.
   const_astr name = minibuf_read_function_name ("Where is command: ");
   gather_bindings_state g;
 
-  ok = leNIL;
+  ok = false;
 
   if (name)
     {
@@ -548,13 +433,13 @@ Argument is a command name.
       if (g.f)
         {
           g.bindings = astr_new ();
-          walk_bindings (root_bindings, gather_bindings, &g);
+          walk_bindings (gather_bindings, &g);
 
           if (astr_len (g.bindings) == 0)
             minibuf_write ("%s is not on any key", astr_cstr (name));
           else
             minibuf_write ("%s is on %s", astr_cstr (name), astr_cstr (g.bindings));
-          ok = leT;
+          ok = true;
         }
     }
 }
@@ -573,7 +458,7 @@ write_bindings_list (va_list ap _GL_UNUSED_PARAMETER)
   bprintf ("%-15s %s\n", "key", "binding");
   bprintf ("%-15s %s\n", "---", "-------");
 
-  walk_bindings (root_bindings, print_binding, NULL);
+  walk_bindings (print_binding, NULL);
 }
 
 DEFUN ("describe-bindings", describe_bindings)
