@@ -29,7 +29,6 @@
 
 #include "main.h"
 #include "extern.h"
-#include "memrmem.h"
 
 
 /*
@@ -606,16 +605,16 @@ With a nil argument, kill the current buffer.
       if (bp == NULL)
         {
           minibuf_error ("Buffer `%s' not found", astr_cstr (buf));
-          ok = leNIL;
+          ok = false;
         }
     }
   else
     bp = cur_bp;
 
-  if (ok == leT)
+  if (ok)
     {
       if (!check_modified_buffer (bp))
-        ok = leNIL;
+        ok = false;
       else
         kill_buffer (bp);
     }
@@ -635,7 +634,7 @@ make_buffer_completion (void)
 
 /*
  * Check if the buffer has been modified.  If so, asks the user if
- * he/she wants to save the changes.  If the response is positive, return
+ * they want to save the changes.  If the response is positive, return
  * true, else false.
  */
 bool
