@@ -35,7 +35,7 @@ void set_this_command (Function cmd);
 size_t do_binding_completion (astr as);
 gl_list_t get_key_sequence (void);
 Function get_function_by_keys (gl_list_t keys);
-le *call_command (Function f, int uniarg, bool uniflag, le *branch);
+bool call_command (Function f, long uniarg, le *branch);
 void get_and_run_command (void);
 void init_default_bindings (void);
 
@@ -43,7 +43,7 @@ void init_default_bindings (void);
 bool insert_char (int c);
 bool delete_char (void);
 bool replace_estr (size_t del, const_estr es);
-bool insert_estr (const_estr as);
+bool insert_estr (const_estr es);
 #define FIELD(ty, field)                                \
   ty get_buffer_ ## field (const Buffer bp);           \
   void set_buffer_ ## field (Buffer bp, ty field);
@@ -64,7 +64,6 @@ _GL_ATTRIBUTE_PURE size_t buffer_next_line (Buffer bp, size_t o);
 _GL_ATTRIBUTE_PURE size_t buffer_start_of_line (Buffer bp, size_t o);
 _GL_ATTRIBUTE_PURE size_t buffer_end_of_line (Buffer bp, size_t o);
 _GL_ATTRIBUTE_PURE size_t buffer_line_len (Buffer bp, size_t o);
-_GL_ATTRIBUTE_PURE size_t get_region_size (const Region r);
 _GL_ATTRIBUTE_PURE size_t get_buffer_line_o (Buffer bp);
 _GL_ATTRIBUTE_PURE char get_buffer_char (Buffer bp, size_t o);
 void destroy_buffer (Buffer bp);
@@ -84,6 +83,7 @@ bool warn_if_readonly_buffer (void);
 #undef FIELD
 _GL_ATTRIBUTE_PURE Region region_new (size_t o1, size_t o2);
 Region calculate_the_region (void);
+_GL_ATTRIBUTE_PURE size_t get_region_size (const Region r);
 bool delete_region (const Region r);
 _GL_ATTRIBUTE_PURE bool region_contains (Region r, size_t o);
 void set_temporary_buffer (Buffer bp);
@@ -132,18 +132,17 @@ void ding (void);
 extern le *leNIL, *leT;
 _GL_ATTRIBUTE_PURE size_t countNodes (le * branch);
 void leEval (le * list);
-le *execute_with_uniarg (int uniarg, bool (*forward) (void), bool (*backward) (void));
-le *move_with_uniarg (int uniarg, bool (*move) (ptrdiff_t dir));
-le *execute_function (const char *name, int uniarg, bool is_uniarg);
+bool execute_with_uniarg (long uniarg, bool (*forward) (void), bool (*backward) (void));
+bool move_with_uniarg (long uniarg, bool (*move) (ptrdiff_t dir));
+bool execute_function (const char *name, long uniarg, bool is_uniarg);
 _GL_ATTRIBUTE_PURE Function get_function (const char *name);
 _GL_ATTRIBUTE_PURE const char *get_function_doc (const char *name);
-_GL_ATTRIBUTE_PURE bool get_function_interactive (const char *name);
+_GL_ATTRIBUTE_PURE int get_function_interactive (const char *name);
 _GL_ATTRIBUTE_PURE const char *get_function_name (Function p);
 _GL_ATTRIBUTE_FORMAT_PRINTF(1, 2) const_astr minibuf_read_function_name (const char *fmt, ...);
 void init_eval (void);
 
 /* file.c ----------------------------------------------------------------- */
-bool exist_file (const char *filename);
 astr get_home_dir (void);
 astr agetcwd (void);
 bool expand_path (astr path);
@@ -228,13 +227,11 @@ _GL_ATTRIBUTE_FORMAT_PRINTF(1, 2) void minibuf_write (const char *fmt, ...);
 _GL_ATTRIBUTE_FORMAT_PRINTF(1, 2) void minibuf_error (const char *fmt, ...);
 _GL_ATTRIBUTE_FORMAT_PRINTF(1, 3) const_astr minibuf_read (const char *fmt, const char *value, ...);
 _GL_ATTRIBUTE_FORMAT_PRINTF(1, 2) long minibuf_read_number (const char *fmt, ...);
-bool minibuf_test_in_completions (const char *ms, gl_list_t completions);
 _GL_ATTRIBUTE_FORMAT_PRINTF(1, 2) int minibuf_read_yesno (const char *fmt, ...);
 _GL_ATTRIBUTE_FORMAT_PRINTF(1, 5) const_astr minibuf_read_completion (const char *fmt, const char *value, Completion cp,
                                                                       History hp, ...);
 _GL_ATTRIBUTE_FORMAT_PRINTF(1, 0) const_astr minibuf_vread_completion (const char *fmt, const char *value, Completion cp,
                                                                        History hp, const char *empty_err,
-                                                                       bool (*test) (const char *s, gl_list_t completions),
                                                                        const char *invalid_err, va_list ap);
 _GL_ATTRIBUTE_FORMAT_PRINTF(1, 4) const_astr minibuf_read_filename (const char *fmt, const char *value,
                                                                     const char *file, ...);
@@ -312,6 +309,6 @@ void window_resync (Window wp);
  * Declare external Zile functions.
  */
 #define X(zile_name, c_name, interactive, doc)   \
-  le *F_ ## c_name (long uniarg, bool is_uniarg, le * l);
+  bool F_ ## c_name (long uniarg, le * l);
 #include "tbl_funcs.h"
 #undef X
