@@ -37,7 +37,7 @@
 #include "main.h"
 #include "extern.h"
 
-bool
+static bool
 exist_file (const char *filename)
 {
   struct stat st;
@@ -244,8 +244,8 @@ find_file (const char *filename)
 DEFUN_ARGS ("find-file", find_file,
             STR_ARG (filename))
 /*+
-Edit file @i{filename}.
-Switch to a buffer visiting file @i{filename},
+Edit file FILENAME.
+Switch to a buffer visiting file FILENAME,
 creating one if none already exists.
 +*/
 {
@@ -260,22 +260,22 @@ creating one if none already exists.
     }
 
   if (filename == NULL || astr_len (filename) == 0)
-    ok = leNIL;
+    ok = false;
 
-  if (ok != leNIL)
-    ok = bool_to_lisp (find_file (astr_cstr (filename)));
+  if (ok)
+    ok = find_file (astr_cstr (filename));
 }
 END_DEFUN
 
 DEFUN ("find-file-read-only", find_file_read_only)
 /*+
-Edit file @i{filename} but don't allow changes.
-Like `find-file' but marks buffer as read-only.
-Use @kbd{M-x toggle-read-only} to permit editing.
+Edit file FILENAME but don't allow changes.
+Like `find-file', but marks buffer as read-only.
+Use M-x toggle-read-only to permit editing.
 +*/
 {
-  ok = F_find_file (uniarg, is_uniarg, arglist);
-  if (ok == leT)
+  ok = F_find_file (uniarg, arglist);
+  if (ok)
     set_buffer_readonly (cur_bp, true);
 }
 END_DEFUN
@@ -296,13 +296,13 @@ If the current buffer now contains an empty file that you just visited
     base = base_name (buf);
   const_astr ms = minibuf_read_filename ("Find alternate: ", buf, base);
 
-  ok = leNIL;
+  ok = false;
   if (ms == NULL)
     ok = FUNCALL (keyboard_quit);
   else if (astr_len (ms) > 0 && check_modified_buffer (cur_bp))
     {
       kill_buffer (cur_bp);
-      ok = bool_to_lisp (find_file (astr_cstr (ms)));
+      ok = find_file (astr_cstr (ms));
     }
 }
 END_DEFUN
@@ -310,7 +310,7 @@ END_DEFUN
 DEFUN_ARGS ("switch-to-buffer", switch_to_buffer,
             STR_ARG (buf))
 /*+
-Select buffer @i{buffer} in the current window.
+Select buffer BUFFER in the current window.
 +*/
 {
   Buffer bp = ((get_buffer_next (cur_bp) != NULL) ? get_buffer_next (cur_bp) : head_bp);
@@ -326,7 +326,7 @@ Select buffer @i{buffer} in the current window.
         ok = FUNCALL (keyboard_quit);
     }
 
-  if (ok == leT)
+  if (ok)
     {
       if (buf && astr_len (buf) > 0)
         {
@@ -355,7 +355,7 @@ Puts mark after the inserted text.
   Buffer def_bp = ((get_buffer_next (cur_bp) != NULL) ? get_buffer_next (cur_bp) : head_bp);
 
   if (warn_if_readonly_buffer ())
-    return leNIL;
+    return false;
 
   STR_INIT (buf)
   else
@@ -367,7 +367,7 @@ Puts mark after the inserted text.
         ok = FUNCALL (keyboard_quit);
     }
 
-  if (ok == leT)
+  if (ok)
     {
       Buffer bp;
 
@@ -377,13 +377,13 @@ Puts mark after the inserted text.
           if (bp == NULL)
             {
               minibuf_error ("Buffer `%s' not found", astr_cstr (buf));
-              ok = leNIL;
+              ok = false;
             }
         }
       else
         bp = def_bp;
 
-      if (ok != leNIL)
+      if (ok)
         {
           insert_buffer (bp);
           FUNCALL (set_mark_command);
@@ -400,7 +400,7 @@ Set mark after the inserted text.
 +*/
 {
   if (warn_if_readonly_buffer ())
-    return leNIL;
+    return false;
 
   STR_INIT (file)
   else
@@ -412,9 +412,9 @@ Set mark after the inserted text.
     }
 
   if (file == NULL || astr_len (file) == 0)
-    ok = leNIL;
+    ok = false;
 
-  if (ok != leNIL)
+  if (ok)
     {
       estr es = estr_readf (astr_cstr (file));
       if (es)
@@ -424,7 +424,7 @@ Set mark after the inserted text.
         }
       else
         {
-          ok = leNIL;
+          ok = false;
           minibuf_error ("%s: %s", astr_cstr (file), strerror (errno));
         }
     }
@@ -466,7 +466,7 @@ write_to_disk (Buffer bp, const char *filename, mode_t mode)
 static astr
 create_backup_filename (const char *filename, const char *backupdir)
 {
-  astr res;
+  astr res = NULL;
 
   /* Prepend the backup directory path to the filename */
   if (backupdir)
@@ -484,7 +484,8 @@ create_backup_filename (const char *filename, const char *backupdir)
         buf = NULL;
       res = buf;
     }
-  else
+
+  if (res == NULL)
     res = astr_new_cstr (filename);
 
   return astr_cat_char (res, '~');
@@ -500,7 +501,7 @@ backup_and_write (Buffer bp, const char *filename)
   /* Make backup of original file. */
   int fd, backup = get_variable_bool ("make-backup-files");
   if (!get_buffer_backup (bp) && backup
-      && (fd = open (filename, O_RDWR, 0)) != -1)
+      && (fd = open (filename, O_RDWR)) != -1)
     {
       close (fd);
 
@@ -528,24 +529,23 @@ backup_and_write (Buffer bp, const char *filename)
   return false;
 }
 
-static le *
+static bool
 write_buffer (Buffer bp, bool needname, bool confirm,
               const char *name0, const char *prompt)
 {
   bool ans = true;
-  le * ok = leT;
+  bool ok = true;
   const_astr name;
 
   if (!needname)
     name = astr_new_cstr (name0);
-
-  if (needname)
+  else
     {
       name = minibuf_read_filename ("%s", "", NULL, prompt);
       if (name == NULL)
         return FUNCALL (keyboard_quit);
       if (astr_len (name) == 0)
-        return leNIL;
+        return false;
       confirm = true;
     }
 
@@ -581,7 +581,7 @@ write_buffer (Buffer bp, bool needname, bool confirm,
       else if (ans == false)
         minibuf_error ("Canceled");
       if (ans != true)
-        ok = leNIL;
+        ok = false;
     }
 
   if (ans == true)
@@ -599,13 +599,13 @@ write_buffer (Buffer bp, bool needname, bool confirm,
           undo_set_unchanged (get_buffer_last_undop (bp));
         }
       else
-        ok = leNIL;
+        ok = false;
     }
 
   return ok;
 }
 
-static le *
+static bool
 save_buffer (Buffer bp)
 {
   if (get_buffer_modified (bp))
@@ -613,7 +613,7 @@ save_buffer (Buffer bp)
                          "File to save in: ");
 
   minibuf_write ("(No changes need to be saved)");
-  return leT;
+  return true;
 }
 
 DEFUN ("save-buffer", save_buffer)
@@ -628,7 +628,7 @@ END_DEFUN
 
 DEFUN ("write-file", write_file)
 /*+
-Write current buffer into file @i{filename}.
+Write current buffer into file FILENAME.
 This makes the buffer visit that file, and marks it as not modified.
 
 Interactively, confirmation is required unless you supply a prefix argument.
@@ -710,7 +710,7 @@ DEFUN ("save-some-buffers", save_some_buffers)
 Save some modified file-visiting buffers.  Asks user about each one.
 +*/
 {
-  ok = bool_to_lisp (save_some_buffers ());
+  ok = save_some_buffers ();
 }
 END_DEFUN
 
@@ -720,7 +720,7 @@ Offer to save each buffer, then kill this Zile process.
 +*/
 {
   if (!save_some_buffers ())
-    return leNIL;
+    return false;
 
   for (Buffer bp = head_bp; bp != NULL; bp = get_buffer_next (bp))
     if (get_buffer_modified (bp) && !get_buffer_needname (bp))
@@ -732,7 +732,7 @@ Offer to save each buffer, then kill this Zile process.
             if (ans == -1)
               return FUNCALL (keyboard_quit);
             else if (!ans)
-              return leNIL;
+              return false;
             break;
           }
         break; /* We have found a modified buffer, so stop. */
@@ -774,7 +774,7 @@ DEFUN_ARGS ("cd", cd,
 Make DIR become the current buffer's default directory.
 +*/
 {
-  if (arglist == NULL)
+  if (arglist == leNIL)
     dir = minibuf_read_filename ("Change default directory: ",
                                  astr_cstr (get_buffer_dir (cur_bp)), NULL);
 
@@ -787,12 +787,12 @@ Make DIR become the current buffer's default directory.
       if (stat (astr_cstr (dir), &st) != 0 || !S_ISDIR (st.st_mode))
         {
           minibuf_error ("`%s' is not a directory", astr_cstr (dir));
-          ok = leNIL;
+          ok = false;
         }
       else if (chdir (astr_cstr (dir)) == -1)
         {
           minibuf_write ("%s: %s", astr_cstr (dir), strerror (errno));
-          ok = leNIL;
+          ok = false;
         }
     }
 }
