@@ -50,7 +50,7 @@ Cancel current command.
 {
   deactivate_mark ();
   minibuf_error ("Quit");
-  ok = leNIL;
+  ok = false;
 }
 END_DEFUN
 
@@ -147,10 +147,8 @@ Display a list of names of existing buffers.
 The list is displayed in a buffer named `*Buffer List*'.
 Note that buffers with names starting with spaces are omitted.
 
-@itemize -
-The @samp{M} column contains a @samp{*} for buffers that are modified.
-The @samp{R} column contains a @samp{%} for buffers that are read-only.
-@end itemize
+The \"R\" column has a \"%\" if the buffer is read-only.
+The \"M\" column has a \"*\" if it is modified.
 +*/
 {
   write_temp_buffer ("*Buffer List*", true, write_buffers_list, cur_wp);
@@ -188,11 +186,11 @@ Just C-u as argument means to use the current column.
   long fill_col = (lastflag & FLAG_UNIARG_EMPTY) ? o : (unsigned long) uniarg;
   char *buf = NULL;
 
-  if (!(lastflag & FLAG_SET_UNIARG) && arglist == NULL)
+  if (!(lastflag & FLAG_SET_UNIARG) && arglist == leNIL)
     {
       fill_col = minibuf_read_number ("Set fill-column to (default %zu): ", o);
       if (fill_col == LONG_MAX)
-        return leNIL;
+        return false;
       else if (fill_col == LONG_MAX - 1)
         fill_col = o;
     }
@@ -204,7 +202,7 @@ Just C-u as argument means to use the current column.
       else
         {
           minibuf_error ("set-fill-column requires an explicit argument");
-          ok = leNIL;
+          ok = false;
         }
     }
   else
@@ -215,7 +213,7 @@ Just C-u as argument means to use the current column.
                      get_variable ("fill-column"));
     }
 
-  if (ok == leT)
+  if (ok)
     set_variable ("fill-column", buf);
 }
 END_DEFUN
@@ -248,7 +246,7 @@ Put the mark where point is now, and point where the mark is now.
   if (get_buffer_mark (cur_bp) == NULL)
     {
       minibuf_error ("No mark set in this buffer");
-      return leNIL;
+      return false;
     }
 
   size_t o = get_buffer_pt (cur_bp);
@@ -285,11 +283,11 @@ END_DEFUN
 DEFUN ("universal-argument", universal_argument)
 /*+
 Begin a numeric argument for the following command.
-Digits or minus sign following @kbd{C-u} make up the numeric argument.
-@kbd{C-u} following the digits or minus sign ends the argument.
-@kbd{C-u} without digits or minus sign provides 4 as argument.
-Repeating @kbd{C-u} without digits or minus sign multiplies the argument
-by 4 each time.
+Digits or minus sign following \\[universal-argument] make up the numeric argument.
+\\[universal-argument] following the digits or minus sign ends the argument.
+\\[universal-argument] without digits or minus sign provides 4 as argument.
+Repeating \\[universal-argument] without digits or minus sign
+ multiplies the argument by 4 each time.
 +*/
 {
   int i = 0, arg = 1, sgn = 1;
@@ -358,7 +356,7 @@ by 4 each time.
         }
     }
 
-  if (ok == leT)
+  if (ok)
     {
       last_uniarg = arg * sgn;
       thisflag |= FLAG_SET_UNIARG;
@@ -432,7 +430,7 @@ END_DEFUN
 static inline bool
 isopenbracketchar (int c, bool single_quote, bool double_quote)
 {
-  return ((c == '(') || (c == '[') || ( c== '{') ||
+  return ((c == '(') || (c == '[') || (c == '{') ||
           ((c == '\"') && !double_quote) ||
           ((c == '\'') && !single_quote));
 }
@@ -661,17 +659,17 @@ transpose_subr (bool (*move_func) (ptrdiff_t dir))
   return true;
 }
 
-static le *
+static bool
 transpose (int uniarg, bool (*move) (ptrdiff_t dir))
 {
   if (warn_if_readonly_buffer ())
-    return leNIL;
+    return false;
 
   bool ret = true;
   for (unsigned long uni = 0; ret && uni < (unsigned) abs (uniarg); ++uni)
     ret = transpose_subr (move);
 
-  return bool_to_lisp (ret);
+  return ret;
 }
 
 DEFUN ("transpose-chars", transpose_chars)
@@ -701,7 +699,7 @@ END_DEFUN
 
 DEFUN ("transpose-sexps", transpose_sexps)
 /*+
-Like @kbd{M-x transpose-words} but applies to sexps.
+Like `transpose-words', but applies to sexps.
 +*/
 {
   ok = transpose (uniarg, move_sexp);
@@ -720,15 +718,14 @@ With argument 0, interchanges line point is in with line mark is in.
 END_DEFUN
 
 
-static le *
+static bool
 mark (int uniarg, Function func)
 {
-  le * ret;
   FUNCALL (set_mark_command);
-  ret = func (uniarg, true, NULL);
-  if (ret)
+  bool ok = func (uniarg, NULL);
+  if (ok)
     FUNCALL (exchange_point_and_mark);
-  return ret;
+  return ok;
 }
 
 DEFUN ("mark-word", mark_word)
@@ -742,8 +739,8 @@ END_DEFUN
 
 DEFUN ("mark-sexp", mark_sexp)
 /*+
-Set mark @i{arg} sexps from point.
-The place mark goes is the same place @kbd{C-M-f} would
+Set mark ARG sexps from point.
+The place mark goes is the same place \\[forward-sexp] would
 move to with the same argument.
 +*/
 {
@@ -759,15 +756,15 @@ Precisely, if point is on line I, move to the start of line I + N.
 +*/
 {
   INT_OR_UNIARG_INIT (n);
-  if (ok == leT)
+  if (ok)
     {
       FUNCALL (beginning_of_line);
-      ok = bool_to_lisp (move_line (n));
+      ok = move_line (n);
     }
 }
 END_DEFUN
 
-static le *
+static bool
 move_paragraph (int uniarg, bool (*forward) (void), bool (*backward) (void),
                      Function line_extremum)
 {
@@ -788,9 +785,9 @@ move_paragraph (int uniarg, bool (*forward) (void), bool (*backward) (void),
   if (is_empty_line ())
     FUNCALL (beginning_of_line);
   else
-    line_extremum (1, false, NULL);
+    line_extremum (1, leNIL);
 
-  return leT;
+  return true;
 }
 
 DEFUN ("backward-paragraph", backward_paragraph)
@@ -862,7 +859,7 @@ Fill paragraph at or after point.
   while ((ret = fill_break_line ()) == true)
     ;
   if (ret == -1)
-    ok = leNIL;
+    ok = false;
 
   goto_offset (get_marker_o (m));
   unchain_marker (m);
@@ -904,7 +901,7 @@ setcase_word_lowercase (void)
 DEFUN_ARGS ("downcase-word", downcase_word,
             INT_OR_UNIARG (arg))
 /*+
-Convert following word (or @i{arg} words) to lower case, moving over.
+Convert following word (or ARG words) to lower case, moving over.
 +*/
 {
   INT_OR_UNIARG_INIT (arg);
@@ -921,7 +918,7 @@ setcase_word_uppercase (void)
 DEFUN_ARGS ("upcase-word", upcase_word,
             INT_OR_UNIARG (arg))
 /*+
-Convert following word (or @i{arg} words) to upper case, moving over.
+Convert following word (or ARG words) to upper case, moving over.
 +*/
 {
   INT_OR_UNIARG_INIT (arg);
@@ -938,7 +935,7 @@ setcase_word_capitalize (void)
 DEFUN_ARGS ("capitalize-word", capitalize_word,
             INT_OR_UNIARG (arg))
 /*+
-Capitalize the following word (or @i{arg} words), moving over.
+Capitalize the following word (or ARG words), moving over.
 This gives the word(s) a first character in upper case
 and the rest lower case.
 +*/
@@ -951,11 +948,11 @@ END_DEFUN
 /*
  * Set the region case.
  */
-static le *
+static bool
 setcase_region (int (*func) (int))
 {
   if (warn_if_readonly_buffer () || warn_if_no_mark ())
-    return leNIL;
+    return false;
 
   Region r = calculate_the_region ();
   Marker m = point_marker ();
@@ -969,7 +966,7 @@ setcase_region (int (*func) (int))
   goto_offset (get_marker_o (m));
   unchain_marker (m);
 
-  return leT;
+  return true;
 }
 
 DEFUN ("upcase-region", upcase_region)
@@ -1029,7 +1026,7 @@ done_read (void *data, size_t n, void *priv)
   astr_cat_nstr (((pipe_data *) priv)->out, (const char *)data, n);
 }
 
-static le *
+static bool
 pipe_command (const_astr cmd, astr input, bool do_insert, bool do_replace)
 {
   const char *prog_argv[] = { "/bin/sh", "-c", astr_cstr (cmd), NULL };
@@ -1037,7 +1034,7 @@ pipe_command (const_astr cmd, astr input, bool do_insert, bool do_replace)
   if (pipe_filter_ii_execute (PACKAGE_NAME, "/bin/sh", prog_argv, true, false,
                               prepare_write, done_write, prepare_read, done_read,
                               &inout) != 0)
-    return leNIL;
+    return false;
 
   char *eol = strchr (astr_cstr (inout.out), '\n');
 
@@ -1067,7 +1064,7 @@ pipe_command (const_astr cmd, astr input, bool do_insert, bool do_replace)
         }
     }
 
-  return leT;
+  return true;
 }
 
 static const_astr
@@ -1090,7 +1087,7 @@ DEFUN_ARGS ("shell-command", shell_command,
             STR_ARG (cmd)
             BOOL_ARG (insert))
 /*+
-Execute string @i{command} in inferior shell; display output, if any.
+Execute string COMMAND in inferior shell; display output, if any.
 With prefix argument, insert the command's output at point.
 
 Command is executed synchronously.  The output appears in the buffer
@@ -1099,7 +1096,7 @@ in the echo area, it is shown there, but it is nonetheless available
 in buffer `*Shell Command Output*' even though that buffer is not
 automatically displayed.
 
-The optional second argument @i{output-buffer}, if non-nil,
+The optional second argument OUTPUT-BUFFER, if non-nil,
 says to insert the output in the current buffer.
 +*/
 {
@@ -1151,7 +1148,7 @@ The output is available in that buffer in both cases.
   if (cmd != NULL)
     {
       if (warn_if_no_mark ())
-        ok = leNIL;
+        ok = false;
       else
         ok = pipe_command (cmd, estr_get_as (get_buffer_region (cur_bp, calculate_the_region ())), insert, true);
     }
@@ -1164,7 +1161,7 @@ Delete the text between point and mark.
 +*/
 {
   if (warn_if_no_mark () || !delete_region (calculate_the_region ()))
-    ok = leNIL;
+    ok = false;
   else
     deactivate_mark ();
 }
@@ -1181,12 +1178,12 @@ On nonblank line, delete any immediately following blank lines.
   Region r = region_new (get_buffer_line_o (cur_bp), get_buffer_line_o (cur_bp));
 
   /* Find following blank lines.  */
-  if (FUNCALL (forward_line) == leT && is_blank_line ())
+  if (FUNCALL (forward_line) && is_blank_line ())
     {
       set_region_start (r, get_buffer_pt (cur_bp));
       do
         set_region_end (r, buffer_next_line (cur_bp, get_buffer_pt (cur_bp)));
-      while (FUNCALL (forward_line) == leT && is_blank_line ());
+      while (FUNCALL (forward_line) && is_blank_line ());
       set_region_end (r, MIN (get_region_end (r), get_buffer_size (cur_bp)));
     }
   goto_offset (get_marker_o (m));
@@ -1198,7 +1195,7 @@ On nonblank line, delete any immediately following blank lines.
       set_region_end (r, MAX (get_region_end (r), buffer_next_line (cur_bp, get_buffer_pt (cur_bp))));
       do
         set_region_start (r, get_buffer_line_o (cur_bp));
-      while (FUNCALL_ARG (forward_line, -1) == leT && is_blank_line ());
+      while (FUNCALL_ARG (forward_line, -1) && is_blank_line ());
       goto_offset (get_marker_o (m));
       if (get_region_start (r) != get_buffer_line_o (cur_bp) ||
           get_region_end (r) > buffer_next_line (cur_bp, get_buffer_pt (cur_bp)))
