@@ -95,7 +95,7 @@ kill_line (bool whole_line)
 
   if (ok && (whole_line || only_blanks_to_end_of_line) && !eobp ())
     {
-      if (FUNCALL (delete_char) == leNIL)
+      if (!FUNCALL (delete_char))
         return false;
 
       kill_ring_push (estr_new_astr (astr_new_cstr ("\n")));
@@ -121,7 +121,7 @@ DEFUN_ARGS ("kill-line", kill_line,
             INT_OR_UNIARG (arg))
 /*+
 Kill the rest of the current line; if no nonblanks there, kill thru newline.
-With prefix argument @i{arg}, kill that many lines from point.
+With prefix argument ARG, kill that many lines from point.
 Negative arguments kill lines backward.
 With zero argument, kills the text before point on the current line.
 
@@ -135,13 +135,13 @@ with no argument.
   INT_OR_UNIARG_INIT (arg);
 
   if (noarg)
-    ok = bool_to_lisp (kill_line (bolp () && get_variable_bool ("kill-whole-line")));
+    ok = kill_line (bolp () && get_variable_bool ("kill-whole-line"));
   else
     {
       if (arg <= 0)
-        ok = bool_to_lisp (bolp () ||
-                           copy_or_kill_region (true, region_new (get_buffer_line_o (cur_bp), get_buffer_pt (cur_bp))));
-      if (arg != 0 && ok == leT)
+        ok = bolp () ||
+          copy_or_kill_region (true, region_new (get_buffer_line_o (cur_bp), get_buffer_pt (cur_bp)));
+      if (arg != 0 && ok)
         ok = execute_with_uniarg (arg, kill_whole_line, kill_line_backward);
     }
 
@@ -166,18 +166,21 @@ copy_or_kill_the_region (bool kill)
 
 DEFUN ("kill-region", kill_region)
 /*+
-Kill between point and mark.
-The text is deleted but saved in the kill ring.
-The command @kbd{C-y} (yank) can retrieve it from there.
-If the buffer is read-only, Zile will beep and refrain from deleting
-the text, but put the text in the kill ring anyway.  This means that
-you can use the killing commands to copy text from a read-only buffer.
+Kill (\"cut\") text between point and mark.
+This deletes the text from the buffer and saves it in the kill ring.
+The command \\[yank] can retrieve it from there.
+
+Any command that calls this function is a \"kill command\".
 If the previous command was also a kill command,
 the text killed this time appends to the text killed last time
 to make one entry in the kill ring.
+
+If the buffer is read-only, Zile will beep and refrain from deleting
+the text, but put the text in the kill ring anyway.  This means that
+you can use the killing commands to copy text from a read-only buffer.
 +*/
 {
-  ok = bool_to_lisp (copy_or_kill_the_region (true));
+  ok = copy_or_kill_the_region (true);
 }
 END_DEFUN
 
@@ -186,33 +189,33 @@ DEFUN ("copy-region-as-kill", copy_region_as_kill)
 Save the region as if killed, but don't kill it.
 +*/
 {
-  ok = bool_to_lisp (copy_or_kill_the_region (false));
+  ok = copy_or_kill_the_region (false);
 }
 END_DEFUN
 
-static le *
-kill_text (int uniarg, Function mark_func)
+static bool
+kill_text (long uniarg, Function mark_func)
 {
   maybe_destroy_kill_ring ();
 
   if (warn_if_readonly_buffer ())
-    return leNIL;
+    return false;
 
   push_mark ();
-  mark_func (uniarg, true, NULL);
+  mark_func (uniarg, NULL);
   FUNCALL (kill_region);
   pop_mark ();
 
   set_this_command (F_kill_region);
   minibuf_write ("%s", "");		/* Erase "Set mark" message.  */
-  return leT;
+  return true;
 }
 
 DEFUN_ARGS ("kill-word", kill_word,
             INT_OR_UNIARG (arg))
 /*+
 Kill characters forward until encountering the end of a word.
-With argument @i{arg}, do this that many times.
+With argument ARG, do this that many times.
 +*/
 {
   INT_OR_UNIARG_INIT (arg);
@@ -224,7 +227,7 @@ DEFUN_ARGS ("backward-kill-word", backward_kill_word,
             INT_OR_UNIARG (arg))
 /*+
 Kill characters backward until encountering the end of a word.
-With argument @i{arg}, do this that many times.
+With argument ARG, do this that many times.
 +*/
 {
   INT_OR_UNIARG_INIT (arg);
@@ -235,7 +238,7 @@ END_DEFUN
 DEFUN ("kill-sexp", kill_sexp)
 /*+
 Kill the sexp (balanced expression) following the cursor.
-With @i{arg}, kill that many sexps after the cursor.
+With ARG, kill that many sexps after the cursor.
 Negative arg -N means kill N sexps before the cursor.
 +*/
 {
@@ -245,19 +248,19 @@ END_DEFUN
 
 DEFUN ("yank", yank)
 /*+
-Reinsert the last stretch of killed text.
+Reinsert (\"paste\") the last stretch of killed text.
 More precisely, reinsert the stretch of killed text most recently
-killed @i{or} yanked.  Put point at end, and set mark at beginning.
+killed OR yanked.  Put point at end, and set mark at beginning.
 +*/
 {
   if (kill_ring_text == NULL)
     {
       minibuf_error ("Kill ring is empty");
-      return leNIL;
+      return false;
     }
 
   if (warn_if_readonly_buffer ())
-    return leNIL;
+    return false;
 
   FUNCALL (set_mark_command);
   insert_estr (kill_ring_text);
