@@ -82,7 +82,7 @@ int
 fill_break_line (void)
 {
   long n;
-  if (!lisp_to_number (get_variable_bp (cur_bp, "fill-column"), &n) || n < 0)
+  if (!lisp_to_number (get_variable ("fill-column"), &n) || n < 0)
     {
       minibuf_error ("Wrong type argument: number-or-markerp, nil");
       return -1;
@@ -216,7 +216,7 @@ backward_delete_char (void)
 DEFUN_ARGS ("delete-char", delete_char,
             INT_OR_UNIARG (n))
 /*+
-Delete the following @i{n} characters (previous if @i{n} is negative).
+Delete the following N characters (previous if N is negative).
 +*/
 {
   INT_OR_UNIARG_INIT (n);
@@ -227,7 +227,7 @@ END_DEFUN
 DEFUN_ARGS ("backward-delete-char", backward_delete_char,
             INT_OR_UNIARG (n))
 /*+
-Delete the previous @i{n} characters (following if @i{n} is negative).
+Delete the previous N characters (following if N is negative).
 +*/
 {
   INT_OR_UNIARG_INIT (n);
@@ -270,7 +270,7 @@ previous_nonblank_goalc (void)
   size_t cur_goalc = get_goalc ();
 
   /* Find previous non-blank line. */
-  while (FUNCALL_ARG (forward_line, -1) == leT && is_blank_line ());
+  while (FUNCALL_ARG (forward_line, -1) && is_blank_line ());
 
   /* Go to `cur_goalc' in that non-blank line. */
   while (!eolp () && get_goalc () < cur_goalc)
@@ -292,10 +292,10 @@ does nothing.
   size_t target_goalc = 0, cur_goalc = get_goalc ();
   size_t t = tab_width (cur_bp);
 
-  ok = leNIL;
+  ok = false;
 
   if (warn_if_readonly_buffer ())
-    return leNIL;
+    return false;
 
   deactivate_mark ();
 
@@ -337,17 +337,17 @@ does nothing.
           do
             {
               if (cur_goalc % t == 0 && cur_goalc + t <= target_goalc)
-                ok = bool_to_lisp (insert_tab ());
+                ok = insert_tab ();
               else
-                ok = bool_to_lisp (insert_char (' '));
+                ok = insert_char (' ');
             }
-          while (ok == leT && (cur_goalc = get_goalc ()) < target_goalc);
+          while (ok && (cur_goalc = get_goalc ()) < target_goalc);
         }
       else
-        ok = bool_to_lisp (insert_tab ());
+        ok = insert_tab ();
     }
   else
-    ok = bool_to_lisp (insert_tab ());
+    ok = insert_tab ();
 }
 END_DEFUN
 
@@ -382,7 +382,7 @@ the indentation.  Else stay at same point in text.
 +*/
 {
   if (get_variable_bool ("tab-always-indent"))
-    return bool_to_lisp (insert_tab ());
+    return insert_tab ();
   else if (get_goalc () < previous_line_indent ())
     return FUNCALL (indent_relative);
 }
@@ -394,10 +394,10 @@ Insert a newline, then indent.
 Indentation is done using the `indent-for-tab-command' function.
 +*/
 {
-  ok = leNIL;
+  ok = false;
 
   if (warn_if_readonly_buffer ())
-    return leNIL;
+    return false;
 
   deactivate_mark ();
 
@@ -415,7 +415,7 @@ Indentation is done using the `indent-for-tab-command' function.
          there is a space character there in the last non-blank line. */
       if (indent)
         FUNCALL (indent_for_tab_command);
-      ok = leT;
+      ok = true;
     }
 }
 END_DEFUN
