@@ -147,8 +147,6 @@ read_token (tokenname *tokenid, astr as, size_t * pos)
 
       c = read_char (as, pos);
     }
-
-  return tok;
 }
 
 static le *
@@ -214,9 +212,9 @@ Execute a file of Lisp code named FILE.
 +*/
 {
   if (arglist && countNodes (arglist) >= 2)
-    ok = bool_to_lisp (lisp_loadfile (arglist->next->data));
+    ok = lisp_loadfile (arglist->next->data);
   else
-    ok = leNIL;
+    ok = false;
 }
 END_DEFUN
 
