@@ -22,45 +22,34 @@
 #include <config.h>
 
 #include <assert.h>
-#include <stdarg.h>
-#include <stdio.h>
-#include <stdlib.h>
 #include "gl_array_list.h"
 
 #include "main.h"
 #include "extern.h"
 
 
-struct Macro
-{
-  gl_list_t keys;	/* List of keystrokes. */
-  char *name;		/* Name of the macro. */
-  Macro next;		/* Next macro in the list. */
-};
+typedef gl_list_t Macro;	/* List of keystrokes. */
 
 static Macro cur_mp = NULL, cmd_mp = NULL;
 
 static Macro
 macro_new (void)
 {
-  Macro mp = XZALLOC (struct Macro);
-  mp->keys = gl_list_create_empty (GL_ARRAY_LIST,
-                                   NULL, NULL, NULL, true);
-  return mp;
+  return gl_list_create_empty (GL_ARRAY_LIST, NULL, NULL, NULL, true);
 }
 
 static void
 add_macro_key (Macro mp, size_t key)
 {
-  gl_list_add_last (mp->keys, (void *) key);
+  gl_list_add_last (mp, (void *) key);
 }
 
 void
 add_cmd_to_macro (void)
 {
   assert (cmd_mp);
-  for (size_t i = 0; i < gl_list_size (cmd_mp->keys); i++)
-    add_macro_key (cur_mp, (size_t) gl_list_get_at (cmd_mp->keys, i));
+  for (size_t i = 0; i < gl_list_size (cmd_mp); i++)
+    add_macro_key (cur_mp, (size_t) gl_list_get_at (cmd_mp, i));
   cmd_mp = NULL;
 }
 
@@ -77,7 +66,7 @@ void
 remove_key_from_cmd (void)
 {
   assert (cmd_mp);
-  gl_list_remove_at (cmd_mp->keys, gl_list_size (cmd_mp->keys) - 1);
+  gl_list_remove_at (cmd_mp, gl_list_size (cmd_mp) - 1);
 }
 
 void
@@ -91,13 +80,13 @@ DEFUN ("start-kbd-macro", start_kbd_macro)
 /*+
 Record subsequent keyboard input, defining a keyboard macro.
 The commands are recorded even as they are executed.
-Use @kbd{C-x )} to finish recording and make the macro available.
+Use \\[end-kbd-macro] to finish recording and make the macro available.
 +*/
 {
   if (thisflag & FLAG_DEFINING_MACRO)
     {
       minibuf_error ("Already defining a keyboard macro");
-      return leNIL;
+      return false;
     }
 
   if (cur_mp)
@@ -113,14 +102,14 @@ END_DEFUN
 DEFUN ("end-kbd-macro", end_kbd_macro)
 /*+
 Finish defining a keyboard macro.
-The definition was started by @kbd{C-x (}.
-The macro is now available for use via @kbd{C-x e}.
+The definition was started by \\[start-kbd-macro].
+The macro is now available for use via \\[call-last-kbd-macro].
 +*/
 {
   if (!(thisflag & FLAG_DEFINING_MACRO))
     {
       minibuf_error ("Not defining a keyboard macro");
-      return leNIL;
+      return false;
     }
 
   thisflag &= ~FLAG_DEFINING_MACRO;
@@ -150,19 +139,19 @@ call_macro (void)
 
 DEFUN ("call-last-kbd-macro", call_last_kbd_macro)
 /*+
-Call the last keyboard macro that you defined with @kbd{C-x (}.
+Call the last keyboard macro that you defined with \\[start-kbd-macro].
 A prefix argument serves as a repeat count.
 +*/
 {
   if (cur_mp == NULL)
     {
       minibuf_error ("No kbd macro has been defined");
-      return leNIL;
+      return false;
     }
 
   /* FIXME: Call execute-kbd-macro (needs a way to reverse keystrtovec) */
-  /* F_execute_kbd_macro (uniarg, true, leAddDataElement (leNew (NULL), astr_cstr (keyvectostr (cur_mp->keys)), false)); */
-  macro_keys = cur_mp->keys;
+  /* F_execute_kbd_macro (uniarg, true, leAddDataElement (leNew (NULL), astr_cstr (keyvectostr (cur_mp)), false)); */
+  macro_keys = cur_mp;
   execute_with_uniarg (uniarg, call_macro, NULL);
 }
 END_DEFUN
@@ -181,6 +170,6 @@ Execute macro as string of editor command characters.
       execute_with_uniarg (uniarg, call_macro, NULL);
     }
   else
-    ok = leNIL;
+    ok = false;
 }
 END_DEFUN
