@@ -65,7 +65,7 @@ Keys not working properly?  See file://" PATH_DOCDIR "/FAQ\n\
 GNU " PACKAGE_NAME " comes with ABSOLUTELY NO WARRANTY.\n\
 " PACKAGE_NAME " is Free Software--Free as in Freedom--so you can redistribute copies\n\
 of " PACKAGE_NAME " and modify it; see the file COPYING.  Otherwise, a copy can be\n\
-downloaded from http://www.gnu.org/licenses/gpl.html.\n\
+downloaded from https://www.gnu.org/licenses/gpl.html.\n\
 ";
 
 static _Noreturn void
@@ -282,10 +282,9 @@ main (int argc, char **argv)
         {
         case arg_function:
           {
-            le *res = execute_function (arg, 1, false);
-            if (res == NULL)
+            ok = execute_function (arg, 1, false);
+            if (!ok)
               minibuf_error ("Function `%s' not defined", arg);
-            ok = res == leT;
             break;
           }
         case arg_loadfile:
