@@ -50,7 +50,6 @@ typedef struct Region *Region;
 typedef struct Marker *Marker;
 typedef struct History *History;
 typedef struct Undo *Undo;
-typedef struct Macro *Macro;
 typedef struct Binding *Binding;
 typedef struct Buffer *Buffer;
 typedef struct Window *Window;
@@ -101,20 +100,17 @@ typedef enum
 /*
  * The type of a Zile exported function.
  * `uniarg' is the universal argument, if any, whose presence is
- * indicated by `is_uniarg'.
+ * indicated by `list' being `NULL'.
  */
-typedef le * (*Function) (long uniarg, bool is_uniarg, le * list);
-
-/* Turn a bool into a Lisp boolean */
-#define bool_to_lisp(b) ((b) ? leT : leNIL)
+typedef bool (*Function) (long uniarg, le * list);
 
 /* Define an interactive function. */
 #define DEFUN(zile_func, c_func) \
   DEFUN_ARGS(zile_func, c_func, )
 #define DEFUN_ARGS(zile_func, c_func, args) \
-  le * F_ ## c_func (long uniarg _GL_UNUSED_PARAMETER, bool is_uniarg _GL_UNUSED_PARAMETER, le *arglist _GL_UNUSED_PARAMETER) \
+  bool F_ ## c_func (long uniarg _GL_UNUSED_PARAMETER, le *arglist _GL_UNUSED_PARAMETER) \
   {                                                                     \
-    le * ok = leT;                                                      \
+    bool ok = true;                                                     \
     args
 #define END_DEFUN    \
     return ok;       \
@@ -148,7 +144,7 @@ typedef le * (*Function) (long uniarg, bool is_uniarg, le * list);
       if (s != NULL)                            \
         name = strtol (s, NULL, 10);            \
       if (name == LONG_MAX)                     \
-        ok = leNIL;                             \
+        ok = false;                             \
     }
 
 /* Integer argument which can either be argument or uniarg. */
@@ -159,8 +155,7 @@ typedef le * (*Function) (long uniarg, bool is_uniarg, le * list);
   INT_INIT (name)                                            \
   else                                                       \
     {                                                        \
-      if (!(lastflag & FLAG_SET_UNIARG) && !is_uniarg &&     \
-          (arglist == NULL || arglist->next == NULL))        \
+      if (!(lastflag & FLAG_SET_UNIARG) && arglist != NULL)  \
         noarg = true;                                        \
       name = uniarg;                                         \
     }
@@ -179,11 +174,11 @@ typedef le * (*Function) (long uniarg, bool is_uniarg, le * list);
 
 /* Call an interactive function. */
 #define FUNCALL(c_func)                         \
-  F_ ## c_func (1, false, leNIL)
+  F_ ## c_func (1, leNIL)
 
 /* Call an interactive function with a universal argument. */
 #define FUNCALL_ARG(c_func, uniarg)             \
-  F_ ## c_func (uniarg, true, leNIL)
+  F_ ## c_func (uniarg, NULL)
 
 /*--------------------------------------------------------------------------
  * Keyboard handling.
