@@ -1,6 +1,6 @@
 /* Minibuffer handling
 
-   Copyright (c) 1997-2005, 2008-2009, 2011 Free Software Foundation, Inc.
+   Copyright (c) 1997-2011 Free Software Foundation, Inc.
 
    This file is part of GNU Zile.
 
@@ -68,9 +68,9 @@ draw_minibuf_read (const char *prompt, const char *value,
 }
 
 static void
-maybe_close_popup (Completion *cp)
+maybe_close_popup (Completion cp)
 {
-  Window *wp, *old_wp = cur_wp;
+  Window wp, old_wp = cur_wp;
   if (cp != NULL && (get_completion_flags (cp) & CFLAG_POPPEDUP)
       && (wp = find_window ("*Completions*")) != NULL)
     {
@@ -84,9 +84,8 @@ maybe_close_popup (Completion *cp)
     }
 }
 
-castr
-term_minibuf_read (const char *prompt, const char *value, size_t pos,
-               Completion * cp, History * hp)
+const_astr
+term_minibuf_read (const char *prompt, const char *value, size_t pos, Completion cp, History hp)
 {
   if (hp)
     prepare_history (hp);
@@ -104,13 +103,13 @@ term_minibuf_read (const char *prompt, const char *value, size_t pos,
       const char *s;
       switch (lasttab)
         {
-        case COMPLETION_MATCHEDNONUNIQUE:
+        case completion_matchednonunique:
           s = " [Complete, but not unique]";
           break;
-        case COMPLETION_NOTMATCHED:
+        case completion_notmatched:
           s = " [No match]";
           break;
-        case COMPLETION_MATCHED:
+        case completion_matched:
           s = " [Sole completion]";
           break;
         default:
@@ -237,7 +236,7 @@ term_minibuf_read (const char *prompt, const char *value, size_t pos,
               break;
             }
 
-          if (lasttab != -1 && lasttab != COMPLETION_NOTMATCHED
+          if (lasttab != -1 && lasttab != completion_notmatched
               && get_completion_flags (cp) & CFLAG_POPPEDUP)
             {
               completion_scroll_up ();
@@ -250,12 +249,12 @@ term_minibuf_read (const char *prompt, const char *value, size_t pos,
               thistab = completion_try (cp, bs, true);
               switch (thistab)
                 {
-                case COMPLETION_MATCHED:
+                case completion_matched:
                   maybe_close_popup (cp);
                   set_completion_flags (cp, get_completion_flags (cp) & ~CFLAG_POPPEDUP);
                   /* FALLTHROUGH */
-                case COMPLETION_MATCHEDNONUNIQUE:
-                case COMPLETION_NONUNIQUE:
+                case completion_matchednonunique:
+                case completion_nonunique:
                   {
                     bs = astr_new ();
                     if (get_completion_flags (cp) & CFLAG_FILENAME)
@@ -268,7 +267,7 @@ term_minibuf_read (const char *prompt, const char *value, size_t pos,
                     pos = astr_len (as);
                     break;
                   }
-                case COMPLETION_NOTMATCHED:
+                case completion_notmatched:
                   ding ();
                   break;
                 default:
@@ -285,7 +284,7 @@ term_minibuf_read (const char *prompt, const char *value, size_t pos,
             ding ();
           else
             {
-              astr_cpy (as, astr_fmt ("%s%c%s", astr_cstr (astr_substr (as, 0, pos)), c, astr_cstr (astr_substr (as, pos, astr_len (as) - pos))));
+              astr_cpy (as, astr_fmt ("%s%c%s", astr_cstr (astr_substr (as, 0, pos)), (int) c, astr_cstr (astr_substr (as, pos, astr_len (as) - pos))));
               pos++;
             }
         }
